==> keybase-4.7.0.tar.gz: client-4.7.0/shared/chat/conversation/messages/system-invite-accepted/index.tsx <==
import * as React from 'react'
import * as Types from '../../../../constants/types/chat2'
import * as Kb from '../../../../common-adapters'
import * as Styles from '../../../../styles'
import * as TeamTypes from '../../../../constants/types/teams'
import UserNotice from '../user-notice'
import SystemMessageTimestamp from '../system-message-timestamp'
import {typeToLabel} from '../../../../constants/teams'

type Props = {
  message: Types.MessageSystemInviteAccepted
  onViewTeam: () => void
  role: TeamTypes.TeamRoleType
  teamname: string
  you: string
}

const connectedUsernamesProps = {
  colorFollowing: true,
  inline: true,
  onUsernameClicked: 'profile',
  type: 'BodySmallSemibold',
  underline: true,
} as const

const InviteAddedToTeamNotice = (props: Props) => {
  if (props.you === props.message.invitee) {
    return <YouInviteAddedToTeamNotice {...props} />
  }
  const {inviter} = props.message
  // There's not a lot of space to explain the adder / inviter situation,
  // just pretend they were added by the inviter for now.
  return (
    <Kb.Text type="BodySmall">
      was added by{' '}
      {props.you === inviter ? (
        'you'
      ) : (
        <Kb.ConnectedUsernames {...connectedUsernamesProps} usernames={[inviter]} />
      )}
      {typeToLabel[props.role] && ` as a "${typeToLabel[props.role].toLowerCase()}"`}.{' '}
    </Kb.Text>
  )
}

const YouInviteAddedToTeamNotice = (props: Props) => {
  const {timestamp} = props.message
  const {teamname} = props

  const copy = (
    <Kb.Text center={true} type="BodySmallSemibold">
      Welcome to{' '}
      <Kb.Text type="BodySmallSemibold" style={{color: Styles.globalColors.black_50}}>
        {teamname}
      </Kb.Text>
      . Say hi!{' '}
      <Kb.EmojiIfExists
        style={{display: Styles.isMobile ? 'flex' : 'inline-block'}}
        emojiName=":wave:"
        size={14}
      />
    </Kb.Text>
  )

  return (
    <UserNotice
      style={{marginTop: Styles.globalMargins.small}}
      teamname={teamname}
      bgColor={Styles.globalColors.blueLighter2}
      onClickAvatar={props.onViewTeam}
    >
      <Kb.Icon type="icon-team-sparkles-64-40" style={{height: 40, marginTop: -36, width: 64}} />
      <SystemMessageTimestamp timestamp={timestamp} />
      <Kb.Box style={{...Styles.globalStyles.flexBoxColumn, alignItems: 'center'}}>{copy}</Kb.Box>
    </UserNotice>
  )
}

export default InviteAddedToTeamNotice

==> keybase-5.1.1.tar.gz: client-5.1.1/shared/chat/conversation/messages/system-invite-accepted/index.tsx <==
import * as React from 'react'
import * as Types from '../../../../constants/types/chat2'
import * as Kb from '../../../../common-adapters'
import * as TeamTypes from '../../../../constants/types/teams'
import UserNotice from '../user-notice'
import {typeToLabel} from '../../../../constants/teams'

type Props = {
  message: Types.MessageSystemInviteAccepted
  onViewTeam: () => void
  role: TeamTypes.MaybeTeamRoleType
  teamname: string
  you: string
}

const connectedUsernamesProps = {
  colorFollowing: true,
  inline: true,
  onUsernameClicked: 'profile',
  type: 'BodySmallSemibold',
  underline: true,
} as const

const InviteAddedToTeamNotice = (props: Props) => {
  if (props.you === props.message.invitee) {
    return <YouInviteAddedToTeamNotice {...props} />
  }
  const {inviter} = props.message
  // There's not a lot of space to explain the adder / inviter situation,
  // just pretend they were added by the inviter for now.
  return (
    <UserNotice>
      <Kb.Text type="BodySmall">
        was added by{' '}
        {props.you === inviter ? (
          'you'
        ) : (
          <Kb.ConnectedUsernames {...connectedUsernamesProps} usernames={[inviter]} />
        )}
        {typeToLabel[props.role] && ` as a "${typeToLabel[props.role].toLowerCase()}"`}.{' '}
      </Kb.Text>
    </UserNotice>
  )
}

const YouInviteAddedToTeamNotice = (props: Props) => {
  return (
    <UserNotice>
      <Kb.Text type="BodySmall">You joined the team.</Kb.Text>
      <Kb.Text type="BodySmallPrimaryLink" onClick={props.onViewTeam}>
        View all members
      </Kb.Text>
    </UserNotice>
  )
}

export default InviteAddedToTeamNotice
